@@ -9,21 +9,15 @@ itest!(globals {
 });
 
 itest!(fs_promises {
-  args: "run --compat --unstable -A compat/fs_promises.js",
+  args: "run --compat --unstable -A compat/fs_promises.mjs",
   output: "compat/fs_promises.out",
 });
 
 itest!(node_prefix_fs_promises {
-  args: "run --compat --unstable -A compat/node_fs_promises.js",
+  args: "run --compat --unstable -A compat/node_fs_promises.mjs",
   output: "compat/fs_promises.out",
 });
 
-itest!(existing_import_map {
-  args: "run --compat --unstable --import-map compat/existing_import_map.json compat/fs_promises.js",
-  output: "compat/existing_import_map.out",
-  exit_code: 1,
-});
-
 #[test]
 fn globals_in_repl() {
   let (out, _err) = util::run_and_collect_output_with_args(
