@@ -1,20 +1,20 @@
 import {
   assert,
   assertEquals,
+  assertRejects,
   assertThrows,
-  assertThrowsAsync,
   pathToAbsoluteFileUrl,
   unitTest,
 } from "./test_util.ts";
 
-unitTest({ perms: { read: true } }, function readTextFileSyncSuccess() {
+unitTest({ permissions: { read: true } }, function readTextFileSyncSuccess() {
   const data = Deno.readTextFileSync("cli/tests/testdata/fixture.json");
   assert(data.length > 0);
   const pkg = JSON.parse(data);
   assertEquals(pkg.name, "deno");
 });
 
-unitTest({ perms: { read: true } }, function readTextFileSyncByUrl() {
+unitTest({ permissions: { read: true } }, function readTextFileSyncByUrl() {
   const data = Deno.readTextFileSync(
     pathToAbsoluteFileUrl("cli/tests/testdata/fixture.json"),
   );
@@ -23,20 +23,20 @@ unitTest({ perms: { read: true } }, function readTextFileSyncByUrl() {
   assertEquals(pkg.name, "deno");
 });
 
-unitTest({ perms: { read: false } }, function readTextFileSyncPerm() {
+unitTest({ permissions: { read: false } }, function readTextFileSyncPerm() {
   assertThrows(() => {
     Deno.readTextFileSync("cli/tests/testdata/fixture.json");
   }, Deno.errors.PermissionDenied);
 });
 
-unitTest({ perms: { read: true } }, function readTextFileSyncNotFound() {
+unitTest({ permissions: { read: true } }, function readTextFileSyncNotFound() {
   assertThrows(() => {
     Deno.readTextFileSync("bad_filename");
   }, Deno.errors.NotFound);
 });
 
 unitTest(
-  { perms: { read: true } },
+  { permissions: { read: true } },
   async function readTextFileSuccess() {
     const data = await Deno.readTextFile("cli/tests/testdata/fixture.json");
     assert(data.length > 0);
@@ -45,7 +45,7 @@ unitTest(
   },
 );
 
-unitTest({ perms: { read: true } }, async function readTextFileByUrl() {
+unitTest({ permissions: { read: true } }, async function readTextFileByUrl() {
   const data = await Deno.readTextFile(
     pathToAbsoluteFileUrl("cli/tests/testdata/fixture.json"),
   );
@@ -54,29 +54,29 @@ unitTest({ perms: { read: true } }, async function readTextFileByUrl() {
   assertEquals(pkg.name, "deno");
 });
 
-unitTest({ perms: { read: false } }, async function readTextFilePerm() {
-  await assertThrowsAsync(async () => {
+unitTest({ permissions: { read: false } }, async function readTextFilePerm() {
+  await assertRejects(async () => {
     await Deno.readTextFile("cli/tests/testdata/fixture.json");
   }, Deno.errors.PermissionDenied);
 });
 
-unitTest({ perms: { read: true } }, function readTextFileSyncLoop() {
+unitTest({ permissions: { read: true } }, function readTextFileSyncLoop() {
   for (let i = 0; i < 256; i++) {
     Deno.readTextFileSync("cli/tests/testdata/fixture.json");
   }
 });
 
 unitTest(
-  { perms: { read: true } },
+  { permissions: { read: true } },
   async function readTextFileDoesNotLeakResources() {
     const resourcesBefore = Deno.resources();
-    await assertThrowsAsync(async () => await Deno.readTextFile("cli"));
+    await assertRejects(async () => await Deno.readTextFile("cli"));
     assertEquals(resourcesBefore, Deno.resources());
   },
 );
 
 unitTest(
-  { perms: { read: true } },
+  { permissions: { read: true } },
   function readTextFileSyncDoesNotLeakResources() {
     const resourcesBefore = Deno.resources();
     assertThrows(() => Deno.readTextFileSync("cli"));
