@@ -3,7 +3,7 @@ import { assert, assertThrows, unitTest } from "./test_util.ts";
 
 // Note tests for Deno.setRaw is in integration tests.
 
-unitTest({ perms: { read: true } }, function consoleSizeFile() {
+unitTest({ permissions: { read: true } }, function consoleSizeFile() {
   const file = Deno.openSync("cli/tests/testdata/hello.txt");
   assertThrows(() => {
     Deno.consoleSize(file.rid);
@@ -18,7 +18,7 @@ unitTest(function consoleSizeError() {
   }, Deno.errors.BadResource);
 });
 
-unitTest({ perms: { read: true } }, function isatty() {
+unitTest({ permissions: { read: true } }, function isatty() {
   // CI not under TTY, so cannot test stdin/stdout/stderr.
   const f = Deno.openSync("cli/tests/testdata/hello.txt");
   assert(!Deno.isatty(f.rid));
